unit entities.simpletable;

interface

uses
  SysUtils, 
  Generics.Collections, 
  Aurelius.Mapping.Attributes, 
  Aurelius.Types.Blob, 
  Aurelius.Types.DynamicProperties, 
  Aurelius.Types.Nullable, 
  Aurelius.Types.Proxy, 
  Aurelius.Dictionary.Classes, 
  Aurelius.Linq;

type
  TSIMPLETABLE = class;
  TSIMPLETABLEDictionary = class;
  
  [Entity]
  [Table('SIMPLETABLE')]
  [Sequence('GEN_SIMPLETABLE_ID')] // add Generator name from FireBird-DB here
  [Id('FID', TIdGenerator.IdentityOrSequence)] // changed this from [Id('FID', TIdGenerator.None)]
  TSIMPLETABLE = class
  private
    [Column('ID', [TColumnProp.Required])]
    FID: Integer;
    
    [Column('TITLE', [], 50)]
    FTITLE: Nullable<string>;
    
    [Column('DESCRIPTION', [TColumnProp.Lazy], 80)]
    [DBTypeMemo]
    FDESCRIPTION: TBlob;
  public
    property ID: Integer read FID write FID;
    property TITLE: Nullable<string> read FTITLE write FTITLE;
    property DESCRIPTION: TBlob read FDESCRIPTION write FDESCRIPTION;
  end;
  
  ISIMPLETABLEDictionary = interface;
  
  ISIMPLETABLEDictionary = interface(IAureliusEntityDictionary)
    function ID: TLinqProjection;
    function TITLE: TLinqProjection;
    function DESCRIPTION: TLinqProjection;
  end;
  
  TSIMPLETABLEDictionary = class(TAureliusEntityDictionary, ISIMPLETABLEDictionary)
  public
    function ID: TLinqProjection;
    function TITLE: TLinqProjection;
    function DESCRIPTION: TLinqProjection;
  end;
  
  IDictionary = interface(IAureliusDictionary)
    function SIMPLETABLE: ISIMPLETABLEDictionary;
  end;
  
  TDictionary = class(TAureliusDictionary, IDictionary)
  public
    function SIMPLETABLE: ISIMPLETABLEDictionary;
  end;
  
function Dic: IDictionary;

implementation

var
  __Dic: IDictionary;

function Dic: IDictionary;
begin
  if __Dic = nil then __Dic := TDictionary.Create;
  result := __Dic;
end;

{ TSIMPLETABLEDictionary }

function TSIMPLETABLEDictionary.ID: TLinqProjection;
begin
  Result := Prop('ID');
end;

function TSIMPLETABLEDictionary.TITLE: TLinqProjection;
begin
  Result := Prop('TITLE');
end;

function TSIMPLETABLEDictionary.DESCRIPTION: TLinqProjection;
begin
  Result := Prop('DESCRIPTION');
end;

{ TDictionary }

function TDictionary.SIMPLETABLE: ISIMPLETABLEDictionary;
begin
  Result := TSIMPLETABLEDictionary.Create;
end;

initialization
  RegisterEntity(TSIMPLETABLE);

end.
